/*
 * GUI right-click menu header
 *
 * Copyright INOUE Seiichiro <inoue@ainet.or.jp>, licensed under the GPL.
 */
#ifndef __GDIFF_RMENU_H__
#define __GDIFF_RMENU_H__

#ifdef __cplusplus 
extern "C" {
#endif /* __cplusplus */


/* Global function declarations */
extern GtkWidget* rmenu_create(const GtkWidget *fview, gpointer data);

#ifdef __cplusplus
} 
#endif /* __cplusplus */
 
#endif /* __GDIFF_RMENU_H__ */
